@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20220630';
+our $VERSION = '0.20220831';
 
-# Table last modified: 2022-06-30
+# Table last modified: 2022-08-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -83,7 +83,7 @@ our %ZIP_TABLE = (
     '077' => '(?:(?:8(?:6(?:01|60|86)|5[01]1)|029[2356]))',
     '078' => '(?:(?:1(?:79[235-7]|49[235]|39[35])|85(?:55|1[013]|0[1-7])|4(?:19[346-8]|492)|3(?:39[2-4]|792)|2(?:19[23]|692)|039[27]))',
     '079' => '(?:(?:8(?:5(?:85|1[136]|5[05]|0[1357-9])|6(?:5[0-26]|1[0-3]))|0(?:39[2-47]|19[278]|59[235])|1(?:39[367]|192)))',
-    '080' => '(?:(?:8(?:5(?:[67]0|0[1-3]|1[018]|8[58]|5[05]|3[18])|6(?:23|39|42|55|6[06]|0[19]|7[07]|8[068])|7(?:[01][18]))|1(?:49[23]|292)|249[235-8]|019[6-8]))',
+    '080' => '(?:(?:8(?:5(?:[67]0|0[1-3]|1[0158]|8[58]|5[05]|3[18])|6(?:23|39|42|55|6[06]|0[19]|7[07]|8[068])|7(?:[01][18]))|1(?:49[23]|292)|249[235-8]|019[6-8]))',
     '081' => '(?:(?:029[2-5]|8501))',
     '082' => '(?:865[01])',
     '083' => '(?:8(?:585|650))',
@@ -103,10 +103,10 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|4[014]|0[1-57-9]|6[05689]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|0[12578]|7[0-258]|8[1358]|1[013-8]|5[0-689]|4[35-7]|2[13-9]|3[013568])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|5[0-2458]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9]|2[13-58]|1[1-378])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[67]|6[068]|8[0469]|3[1269])|0[01]1))',
+    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|5[0-2458]|8[0348]|4[15-7]|1[1-478]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[67]|6[068]|8[0469]|3[1269])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|7[014-689]|3[0-589]|5[18])|3(?:65|1[023579]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|3[035689]|8[01458]|2[136-8]|5[014-689]|6[068]|4[35-8]|0[1256])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|5[06]|8[05]|7[08]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
     '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|3[13-7]|6[014-689]|7[0-357]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|5[013-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[024]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|0[14689]|[24][17]|1[169]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-378])|5(?:65|1[0-2569]|4[37]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
+    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|0[14689]|[24][17]|1[169]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|4[37]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|0[27]|2[12]|8[48]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|26|80|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
@@ -199,7 +199,7 @@ our %ZIP_TABLE = (
     '211' => '(?:8(?:5(?:40|66|3[03]|2[02]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
     '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[23]))',
     '213' => '(?:85(?:66|0[2357]|2[0-25]|1[125-7]|3[35]|7[0367]|5[0138]|8[06-9]))',
-    '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
+    '214' => '(?:85(?:[26]5|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
     '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|0[158]|8[058]|6[67]|1[12]|5[0458])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|5[0-2568]|7[3-578]|2[0-3]|6[05-8]|0[146]|3[15]|1[1-37]|8[023568])|3(?:3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[08]|0[1256])|79[136-8])|6070))',
+    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|7[3-578]|2[0-3]|6[05-8]|0[146]|3[15]|1[1-37]|8[023568]|5[0-3568])|3(?:3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[089]|0[1256])|79[136-8])|6070))',
     '531' => '(?:(?:8(?:5(?:[67]7|26|88|0[1-3]|1[019]|5[58])|787)|6053))',
     '532' => '(?:8(?:5(?:35|60|88|2[045]|1[1245]|5[58]|0[1578])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -509,7 +509,7 @@ our %ZIP_TABLE = (
     '537' => '(?:8(?:(?:50|91)1|686))',
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
-    '540' => '(?:(?:8(?:5(?:6[06]|5[013589]|4[0147]|2[1267]|8[15-7]|3[03-5]|0[1578]|7[01578]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
+    '540' => '(?:(?:8(?:5(?:6[06]|5[0-3589]|4[0147]|2[1267]|8[15-7]|3[03-5]|0[1578]|7[01578]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
     '541' => '(?:(?:8(?:5(?:5[0136-9]|2[013-689]|1[135-8]|4[0-35-7]|7[2568]|8[1579]|0[1-35689]|6[0136-8]|3[014578])|765)|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|0[1-3]|[58][58])|6(?:01|66|8[68])|921))',
@@ -754,7 +754,7 @@ our %ZIP_TABLE = (
     '793' => '(?:8(?:5(?:[58]5|1[056]|0[19])|601))',
     '794' => '(?:(?:8(?:5(?:[56]5|82|1[018]|0[28])|6(?:1[14]|0[12]))|2(?:[124]92|39[25]|59[23])|1(?:39[23]|[14]92)|019[23]))',
     '795' => '(?:(?:8(?:5(?:10|0[124-8])|60[13])|0392))',
-    '796' => '(?:(?:0(?:29[235]|495|892)|850[12]))',
+    '796' => '(?:(?:0(?:29[235]|495)|850[12]))',
     '797' => '(?:(?:(?:02|1[257])92|85[01]1))',
     '798' => '(?:(?:8(?:6(?:01|1[14])|51[01])|4(?:19[2-7]|292|495)|1(?:39[2357]|192)|3(?:39[23]|792)|2192))',
     '799' => '(?:(?:1(?:5(?:8[128]|9[2-68])|39[2-5]|198|692)|2(?:29[2-4]|49[236]|19[25]|39[23]|69[26])|0(?:19[2-7]|49[235-8])|3(?:19[2-68]|79[23]|292)))',
@@ -772,7 +772,7 @@ our %ZIP_TABLE = (
     '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[258]|49[256]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
     '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|7[025-8]|5[0-79]|[14][0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
-    '814' => '(?:(?:8(?:5(?:65|77|0[135]|2[025]|8[58]|1[0-2]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
+    '814' => '(?:(?:8(?:5(?:65|77|0[135]|8[58]|1[0-2]|2[0245]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
     '816' => '(?:8(?:5(?:[67]7|01|30|[58][05]|1[01])|666))',
     '817' => '(?:(?:1(?:[26]92|797)|85(?:20|1[07])))',
@@ -877,7 +877,7 @@ our %ZIP_TABLE = (
     '918' => '(?:8(?:5(?:4[03]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:4[0134]|2[0-25]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
-    '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|0[15-8]|2[035-79]|3[0269]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
+    '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:[37]0|01|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|4[14-6]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
     '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]|777))',
@@ -906,7 +906,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|40|0[1-46])|7(?:01|65))|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|39[278])|2(?:19[2-4]|39[24])|5(?:49[2-4]|292)|039[238]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|3[0-3579]|0[1-57]|4[013-578]|5[0-35-9]|7[0-25-79]|8[0-689]|1[0-248])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-35-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|3(?:19[578]|393)))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|3[0-3579]|0[1-57]|4[013-578]|5[0-35-9]|7[0-25-79]|8[0-689]|1[0-248])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|3(?:19[578]|393)))',
     '951' => '(?:8(?:5(?:70|4[04]|2[018]|1[0-489]|6[067]|3[01356]|8[0156]|0[2-478]|5[0-6])|6(?:01|40|78|8[056]|5[05]|3[023]|2[029]|1[0-2]|6[68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|50[13])|019[23]))',
@@ -916,7 +916,7 @@ our %ZIP_TABLE = (
     '957' => '(?:(?:8(?:5(?:[34]0|11|22|67|5[058]|8[58]|0[236])|6(?:[68]6|01)|701)|0(?:19[235-7]|293)))',
     '958' => '(?:(?:8(?:5(?:01|33|85|5[58])|6(?:01|86))|0292))',
     '959' => '(?:(?:0(?:29[2-6]|59[235-7]|19[2-4]|39[23]|492)|1(?:29[2-468]|39[2357]|69[235]|79[457])|2(?:6(?:88|93)|39[357]|09[23]|292|711)|3(?:19[2-46]|49[23]|292|993)|4(?:49[57]|392)))',
-    '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|1[1-3568])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
+    '960' => '(?:(?:8(?:5(?:75|4[06]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|0[1-35-9]|1[1-3568])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
     '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[67])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
